'===============================================================================
'Library for the Nokia 3310 display

'This is v2.0 with support for printing bitmap images.

'This is the second of at least two .bas files that must be used together.
'Please see 3310init.bas for instructions.

'===============================================================================

Sub D3310reset
   D3310re = 0
   Waitus 250
   D3310re = 1
End Sub

Sub D3310init
   D3310ce = 0                                              'Display data input enable
   D3310dc = 0                                              'Command mode
   D3310commandout &H21                                     'Extended command mode, horizontal addressing
   D3310commandout &HC8                                     'Middle contrast
   D3310commandout &H06                                     'Temperature setting
   D3310commandout &H13                                     'Bias 1:48
   D3310commandout &H20                                     'Normal command mode, horizontal addressing
   D3310commandout &H0C                                     'Uninverted Screen
   D3310ce = 1                                              'Display data input disable
End Sub

Sub D3310clear

   Local D3310pixelloop As Word                             'Loop variable for the pixels

   D3310ce = 0                                              'Display data input enable
   D3310dc = 0                                              'Command mode
   D3310commandout &H20                                     'Normal command mode, horizontal addressing
   D3310commandout &H80                                     'Set RAM X address to 0
   D3310commandout &H40                                     'Set RAM Y address to 0
   D3310dc = 1                                              'Go to data mode
   For D3310pixelloop = 0 To 503                            'Send 504 blank pixels
      D3310dataout &H00
   Next D3310pixelloop
   D3310ce = 1                                              'Display data input disable
End Sub

Sub D3310invert
   D3310commandout &H0D                                     'Inverted screen
End Sub

Sub D3310uninvert
   D3310commandout &H0C                                     'Uninverted screen
End Sub

Sub D3310commandout(byval D3310value As Byte)
   D3310ce = 0                                              'Display data input enable
   D3310dc = 0                                              'Command mode
   Spiout D3310value , 1
   D3310ce = 1                                              'Display data input disable
End Sub

Sub D3310dataout(byval D3310value As Byte)
   D3310ce = 0                                              'Display data input enable
   D3310dc = 1                                              'Data mode
   Spiout D3310value , 1
   D3310ce = 1                                              'Display data input disable
End Sub

Sub D3310position(byval D3310x As Byte , Byval D3310y As Byte)       'Y is the row (0-5), X is the column (0-13)

   Local D3310byte As Byte                                  'Command or data output

   D3310commandout &H20                                     'Horizontal Addressing

   Waitus 250                                               'Wait for the CE to settle

   D3310ce = 0                                              'Display data input enable
   D3310dc = 0                                              'Command mode

   D3310byte = D3310x * &H06                                'Send horizontal address
   D3310byte = D3310byte + &H80
   Spiout D3310byte , 1

   D3310byte = D3310y + &H40                                'Send vertical address
   Spiout D3310byte , 1

   D3310ce = 1                                              'Display data input disable

End Sub

Sub D3310bmpout                                             'You must Restore D3310bmp* before you call D3310bmpout

   Local D3310pixelloop As Word                             'Loop variable for the pixels
   Local D3310column As Byte                                'Display column output

   D3310ce = 0                                              'Display data input enable
   D3310dc = 0                                              'Command mode
   D3310commandout &H20                                     'Normal command mode, horizontal addressing
   D3310commandout &H80                                     'Set RAM X address to 0
   D3310commandout &H40                                     'Set RAM Y address to 0
   D3310dc = 1                                              'Go to data mode

   For D3310pixelloop = 0 To 503                            'Read and print the 504 pixel columns
      Read D3310column
      Call D3310dataout(d3310column)
   Next D3310pixelloop
   D3310ce = 1                                              'Display data input disable

End Sub

Sub D3310print(byval D3310string As String * 14)

   Local D3310length As Byte                                'Holds the length of D3310string
   Local D3310character As String * 1                       'Holds each consecutive character in turn during display output
   Local D3310stringloop As Byte                            'Loop variable for the string
   Local D3310columnloop As Byte                            'Loop variable for the columns
   Local D3310column As Byte                                'Display column output

   D3310length = Len(d3310string)                           'Establish the number of characters

   For D3310stringloop = 1 To D3310length                   'Loop through the string

      D3310character = Mid(d3310string , D3310stringloop , 1)       'Get the current character

      Select Case D3310character                            'Position the pointer to the correct character in the Eeprom and read the first byte
         Case "0" : Restore Zero
         Case "1" : Restore One
         Case "2" : Restore Two
         Case "3" : Restore Three
         Case "4" : Restore Four
         Case "5" : Restore Five
         Case "6" : Restore Six
         Case "7" : Restore Seven
         Case "8" : Restore Eight
         Case "9" : Restore Nine

         Case "." : Restore Dot

         Case "" : Restore Degree

         Case D3310quotation : Restore Quotation


      End Select

      For D3310columnloop = 1 To 5                          'Read and print each column
         Read D3310column
         Call D3310dataout(d3310column)
      Next D3310columnloop

      D3310column = 0                                       'And print a blank column for inter-character spacing
      Call D3310dataout(d3310column)

   Next D3310stringloop

   D3310ce = 1                                              'Display data input disable

End Sub

'===============================================================================

'ASCII data

'Digits
Zero:
Data &H3E , &H51 , &H49 , &H45 , &H3E
One:
Data &H00 , &H42 , &H7F , &H40 , &H00
Two:
Data &H42 , &H61 , &H51 , &H49 , &H46
Three:
Data &H22 , &H41 , &H49 , &H49 , &H36
Four:
Data &H18 , &H14 , &H12 , &H7F , &H10
Five:
Data &H27 , &H45 , &H45 , &H45 , &H39
Six:
Data &H3E , &H49 , &H49 , &H49 , &H32
Seven:
Data &H61 , &H11 , &H09 , &H05 , &H03
Eight:
Data &H36 , &H49 , &H49 , &H49 , &H36
Nine:
Data &H26 , &H49 , &H49 , &H49 , &H3E



'Special characters

Dot:
Data &H00 , &H60 , &H60 , &H00 , &H00

Degree:
Data &H00 , &H07 , &H05 , &H07 , &H00

Quotation:
Data &H00 , &H07 , &H00 , &H07 , &H00
